Command

Enum Command 

pub enum Command {
    GetFullInfo,
    EnableBufferSizeResponseOnData(bool),
    SetOutput(bool),
    GetRingbufferEmptySampleCount,
    SampleData(SampleData),
}
Command structure for the LaserCube protocol.

Variants



GetFullInfo

Get detailed device information.



EnableBufferSizeResponseOnData(bool)

Enable/disable buffer size responses on data packets.



SetOutput(bool)

Enable/disable laser output.



GetRingbufferEmptySampleCount

Get the number of free samples in the device’s ring buffer.



SampleData(SampleData)

Send point data to render.

Implementations

Source

impl Command

pub fn command_type(&self) -> CommandType

Get the command type associated with this command.

pub fn size(&self) -> usize

Estimate the size in bytes this command will take when serialized.

pub fn write_bytes(&self, buffer: &mut Vec<u8>) -> usize

Write this command into the provided byte buffer.

Returns the number of bytes written.

pub fn to_bytes(&self) -> Vec<u8>

Convenience method to get command bytes as a new Vec